
See the full documentation at https://pyqtcmd.readthedocs.io/en/latest/

Changelog:

1.0.5
=====

  * Drop explicit dependency on PyQt5
  * PyQt6 compatibility

1.0.4
=====

  * Fix labels for undo/redo UICommand mixins
  * Fix label for CompositeCommand

1.0.3
=====

  * Add a `past()` accessor to History
  * Add a `label` argument to CompositeCommand constructor

1.0.2
=====

  * Make associated buttons visible (or not) when the action
    visibility changes

1.0.1
=====

  * Added a `tip` argument to UICommand, which sets both the tooltip
    and the status tip
